============
Contributors
============

People, who contributed to Kibitzr in arbitrary order:

* `Igor Sobolev <https://github.com/yigor>`_
* `Delirious Lettuce <https://github.com/delirious-lettuce>`_
* `Martin Virtel <https://github.com/mvtango>`_
* `Attila Nagy <https://github.com/attilanagy>`_
* `Niklas Heer <https://github.com/niklas-heer>`_
* `Francesco Barresi <https://github.com/cescobarresi>`_
